-- Function Tally.parseItemLink
--
-- Takes in an itemLink string and returns
-- the itemID from that string

function Tally.parseItemLink(itemLink)
  local _, itemId = strsplit(":", itemLink)
  return itemId
end -- function Tally.parseItemLink

-- Function Tally.parseLootEvent
--
-- a loot event has occured
-- parse the loot

function Tally.parseLootEvent()
  -- find how many items are looted
  local numItems = GetNumLootItems()
  
  local lootMobTable = {}
  -- for each looted item
  for index = 1, numItems do
    local lootSlotLink = GetLootSlotLink(index)
    
    if (lootSlotLink ~= nil) then
      local sourceIndex = 1
      local lootSourceTable = {}
      local lootSources = {GetLootSourceInfo(index)}

      while lootSources[sourceIndex] do
        local lootSource = lootSources[sourceIndex]
      
          -- parse the loot source index to get the mob number
          local npcId, mobType = Tally.ParseGUID(lootSource)
      
          if (mobType == "NPC") then
            local lootAmount = lootSources[sourceIndex + 1]
            lootSourceTable[npcId] = lootAmount

            -- Build a table of mobs we have seen.  Each will have its own guid, so we just need to record it once even if we see it on multiple loot items.
	    -- Save the npcId as the value - we already have it and it makes for easy aggregation later!
            lootMobTable[lootSource] = npcId

          end -- if
        sourceIndex = sourceIndex + 2
      end
      
      local itemId = Tally.parseItemLink(lootSlotLink)
      Tally.record_item_loot_by_mob(itemId, lootSourceTable)
    end -- if
  end -- for

  -- Record one loot for each mob we've seen in the list.  If the same type of mob appears multiple times, we'll record for the same npcId multiple times - and that's fine!
  print("Mob table for this loot:")
  Tally.printTable(lootMobTable)
  print("End mob table for this loot")
  for guid, npcId in pairs(lootMobTable) do
    Tally.record_mob_loot(npcId)
  end -- for
end -- function Tally.parseLootEvent

function Tally.parse_mob_kill_event()
end -- function Tally.parse_mob_kill_event

-- test function
function Tally.test(itemId, itemTable)
  Tally.printTable(itemTable)
end -- function Tally.test

-- print a table
function Tally.printTable(incomingTable)
  for k, v in pairs(incomingTable) do
    print(k .. " <--> " .. v)
  end -- for
end -- function Tally.printTable
